@@ -18,11 +18,7 @@ gcvt(double number, size_t ndigit, char *buf)
 		*p2++ = '-';
 	for (i=ndigit-1; i>0 && p1[i]=='0'; i--)
 		ndigit--;
-	/* We have to do that. Since ndigit is unsigned if
-	 * decpt < ndigit, decpt - ndigit will be negative
-	 * which is invalid for unsigned. */
-	i = (int) ndigit;
-	if ((decpt >= 0 && decpt - i > 4)
+	if ((decpt >= 0 && decpt > ndigit + 4)
 	 || (decpt < 0 && decpt < -3)) { /* use E-style */
 		decpt--;
 		*p2++ = *p1++;
