@@ -111,7 +111,8 @@ __nis_getgrnam(char *name, char **more_members, void *info)
             outtmp[i-1] = '\0';
           i = 0;
           c = strrchr(outtmp, ':');
-          *(c+1) = '\0';
+          if (c != NULL)
+               *(c+1) = '\0';
           while (more_members[i] != NULL)
             {
               outtmp = realloc(outtmp, strlen(outtmp)
@@ -120,7 +121,8 @@ __nis_getgrnam(char *name, char **more_members, void *info)
               strcat(outtmp, ",");
               i++;
             }
-          *(strrchr(outtmp, ',')) = '\0';
+          c = strrchr(outtmp, ',');
+          if (c != NULL) *(c) = '\0';
           strcat(outtmp, "\n");
           outkey = outtmp;
         }
