@@ -17,8 +17,10 @@ struct __res_state __res = {0};
 #pragma weak __res_status_location = __normal__res_status_location
 
 /* The one in libpthread will override __res_status_location () */
+struct __res_state *__normal__res_status_location ( void );
+
 struct __res_state *
-__normal__res_status_location ()
+__normal__res_status_location ( void )
 {
   return &_res;
 }
