@@ -296,6 +296,8 @@ rresvport(alport)
 	}
 }
 
+int __check_rhosts_file = 1;
+
 int
 ruserok(const char *rhost, int superuser, const char *ruser,
 	const char *luser)
@@ -332,7 +334,7 @@ again:
 		}
 		(void) fclose(hostf);
 	}
-	if (first == 1) {
+	if (first == 1 && (__check_rhosts_file || superuser)) {
 		struct stat sbuf;
 		struct passwd *pwd;
 		char *pbuf;
@@ -413,17 +415,26 @@ _validuser(FILE *hostf, const char *rhost, const char *luser,
 	if (hostvalid && (uservalid || *user == '\0'))
 	  return -1;
 
-            /* enable host from +@netgroup entry for host */
-        if ('+' == ahost[0] && '@' == ahost[1] && '\0' != ahost[2])
+	if ('+' == ahost[0] && '\0' == ahost[1])
+	  /* enable all hosts if + entry for host */
+	  hostvalid = 1;
+	else if ('+' == ahost[0] && '@' == ahost[1] && '\0' != ahost[2])
+          /* enable host from +@netgroup entry for host */
           hostvalid = _checknetgrouphost(rhost, &ahost[2], baselen);
         else
           hostvalid = _checkhost(rhost, ahost, baselen);
+
             /* enable user from +@netgroup entry for user */
 	/* -@netgroup entry already gave uservalid=1 */
 	if (user[0] == '+')
-	  if (user[1] == '@' && user[2] != '\0')
+	{
+	  if (user[1] == '\0')
+	    /* enable all users if + entry for user */
+	    uservalid = 1;
+	  else if (user[1] == '@' && user[2] != '\0')
 	    uservalid = _checknetgroupuser(ruser, &user[2]);
 	  else uservalid = !strcmp(&user[1], ruser);
+	}
 	else if (user[0] == '-')
 	  uservalid = -uservalid;
 	else
