@@ -55,7 +55,7 @@
 
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "@(#)res_query.c	8.1 (Berkeley) 6/4/93";
-static char rcsid[] = "res_query.c,v 1.3 1995/05/25 05:22:46 hjl Exp";
+static char rcsid[] = "$Id: res_query.c,v 1.7 1996/10/04 22:52:52 hjl Exp $";
 #endif /* LIBC_SCCS and not lint */
 
 #include <sys/param.h>
@@ -81,9 +81,21 @@ extern char *__libc_secure_getenv(const char *);
 #define MAXPACKET	1024
 #endif
 
-char *__hostalias __P((const char *));
-int h_errno;
+#ifdef __STDC__
+char    *__hostalias      __P ((const char *));
+int      res_querydomain  __P ((const char *, const char *, int, int,
+                               u_char *, int));
+int      res_search       __P (( const char *, int, int, u_char *, int ));
+int      res_query        __P (( const char *, int, int, u_char *, int ));
+#else
+char    *__hostalias      ();
+int      res_querydomain  ();
+int      res_search       ();
+int      res_query        ();
+#endif
 
+int h_errno;
+  
 #ifdef __ELF__
 #pragma weak hostalias = __hostalias
 #endif
@@ -98,12 +110,17 @@ int h_errno;
  *
  * Caller must parse answer and determine whether it answers the question.
  */
+#ifdef __STDC__
+int
+res_query( const char *name, int class, int type, u_char *answer, int anslen )
+#else
 int
 res_query(name, class, type, answer, anslen)
-	const char *name;	/* domain name */
-	int class, type;	/* class and type of query */
-	u_char *answer;		/* buffer to put answer */
-	int anslen;		/* size of answer buffer */
+	const char *name;    /* domain name */
+	int class, type;     /* class and type of query */
+	u_char *answer;      /* buffer to put answer */
+	int anslen;          /* size of answer buffer */
+#endif
 {
 	u_char buf[MAXPACKET];
 	register HEADER *hp = (HEADER *) answer;
@@ -174,12 +191,17 @@ res_query(name, class, type, answer, anslen)
  * If enabled, implement search rules until answer or unrecoverable failure
  * is detected.  Error code, if any, is left in h_errno.
  */
+#ifdef __STDC__
+int
+res_search( const char *name, int class, int type, u_char *answer, int anslen )
+#else
 int
 res_search(name, class, type, answer, anslen)
 	const char *name;	/* domain name */
 	int class, type;	/* class and type of query */
 	u_char *answer;		/* buffer to put answer */
 	int anslen;		/* size of answer */
+#endif
 {
 	register const char *cp, * const *domain;
 	HEADER *hp = (HEADER *) answer;
@@ -313,12 +335,18 @@ res_search(name, class, type, answer, anslen)
  * Perform a call on res_query on the concatenation of name and domain,
  * removing a trailing dot from name if domain is NULL.
  */
+#ifdef __STDC__
+int
+res_querydomain( const char *name, const char *domain, int class, int type,
+                u_char *answer, int anslen )
+#else
 int
 res_querydomain(name, domain, class, type, answer, anslen)
 	const char *name, *domain;
-	int class, type;	/* class and type of query */
-	u_char *answer;		/* buffer to put answer */
-	int anslen;		/* size of answer */
+	int class, type;    /* class and type of query */
+	u_char *answer;     /* buffer to put answer */
+	int anslen;         /* size of answer */
+#endif
 {
 	char nbuf[2*MAXDNAME+2];
 	const char *longname = nbuf;
@@ -352,9 +380,14 @@ res_querydomain(name, domain, class, type, answer, anslen)
 	return (res_query(longname, class, type, answer, anslen));
 }
 
+#ifdef __STDC__
+char *
+__hostalias( register const char *name )
+#else
 char *
 __hostalias(name)
 	register const char *name;
+#endif
 {
 	register char *cp1, *cp2;
 	FILE *fp;
