@@ -6,7 +6,7 @@
 int snprintf(char *s, int len, char *format, ...)
 {
 	You are trying to do something very wrong.
-	Don't use this source if you wan't to stay alive!
+	Don't use this source if you want to stay alive!
 
 	va_list args;
 	int result;
