@@ -45,7 +45,9 @@ DEFUN(_IO_fclose, (fp),
   if (fp->_IO_file_flags & _IO_IS_FILEBUF)
     status = _IO_file_close_it(fp);
   else
-    status = fp->_flags & _IO_ERR_SEEN ? -1 : 0;
+    status = 0;
+  if (status == 0 && (fp->_flags & _IO_ERR_SEEN))
+    status = -1;
   _IO_FINISH (fp);
 #ifdef _LIBPTHREAD
   __libc_lock_unlock (__libc_libio_lock);
