@@ -39,10 +39,14 @@ DEFUN(_IO_gets, (buf),
     count = 0;
   else
     {
+      int old_error = _IO_stdin->_IO_file_flags & _IO_ERR_SEEN;
+      _IO_stdin->_IO_file_flags &= ~_IO_ERR_SEEN;
       buf[0] = (char)ch;
       count = _IO_getline(_IO_stdin, buf + 1, INT_MAX, '\n', 0) + 1;
       if (_IO_stdin->_IO_file_flags & _IO_ERR_SEEN)
 	return NULL;
+      else
+	_IO_stdin->_IO_file_flags |= old_error;
     }
   buf[count] = 0;
   return buf;
