@@ -661,12 +661,12 @@ __vfscanf (FILE *s, const char *format, va_list argptr)
 	    {
 	      if (isdigit (c))
 		ADDW (c);
-	      else if (got_e && wp[wpsize - 1] == 'e'
+	      else if (got_e && tolower (wp[wpsize - 1]) == 'e'
 		       && (c == '-' || c == '+'))
 		ADDW (c);
 	      else if (wpsize > 0 && !got_e && tolower (c) == 'e')
 		{
-		  ADDW ('e');
+		  ADDW (c);
 		  got_e = got_dot = 1;
 		}
 	      else if (c == decimal && !got_dot)
@@ -808,6 +808,8 @@ __vfscanf (FILE *s, const char *format, va_list argptr)
 }
 
 #ifdef USE_IN_LIBIO
+int __vfscanf( FILE *, const char *, va_list );
+
 int
 __vfscanf (FILE *s, const char *format, va_list argptr)
 {
