@@ -1,9 +1,19 @@
 #include "libioP.h"
 #include "stdio.h"
 
+#ifndef _LIBPTHREAD
+#ifdef __ELF__
+#ifdef __GNUC__
+void clearerr( FILE * ) __attribute__ ((weak));
+#else
+#pragma weak clearerr
+#endif   /* __GNUC__ */
+#endif   /* __ELF__ */
+#endif   /* _LIBPTHREAD */
+
+
 void
-clearerr(fp)
-     FILE* fp;
+clearerr( FILE* fp )
 {
   CHECK_FILE(fp, /*nothing*/);
 #ifdef _LIBPTHREAD
@@ -15,8 +25,3 @@ clearerr(fp)
 #endif
 }
 
-#ifndef _LIBPTHREAD
-#ifdef __ELF__
-#pragma weak clearerr
-#endif
-#endif
