@@ -3,8 +3,7 @@
 #undef putchar
 
 int
-putchar(c)
-     int c;
+putchar( int c )
 {
 #ifdef _LIBPTHREAD
   int ret;
@@ -19,6 +18,10 @@ putchar(c)
 
 #ifndef _LIBPTHREAD
 #ifdef __ELF__
+#ifdef __GNUC__
+int putchar( int ) __attribute__ ((weak));
+#else
 #pragma weak  putchar
-#endif
-#endif
+#endif   /* __GNUC__ */
+#endif   /* __ELF__ */
+#endif   /* _LIBPTHREAD */
