@@ -124,6 +124,8 @@ static nl_catd loadSet(MCCatT *, MCSetT *);
 #include <sys/mman.h>
 #endif
 
+extern char *__libc_secure_getenv(const char *);
+
 nl_catd
 catopen( const char *name, int type )
 {
@@ -141,13 +143,13 @@ catopen( const char *name, int type )
 	if (stat(catpath, &sbuf)) return(NLERR);
     } else {
 #if BROKEN_SETLOCALE
-	if ((lang = (char *) getenv ("LANG")) == NULL) lang = "C";
+	if ((lang = (char *) __libc_secure_getenv ("LANG")) == NULL) lang = "C";
 #else
 	/* Query the locale from the previous setlocale call in msgcat-libc.c*/
 	if ((lang = (char *) setlocale(LC_MESSAGES,(char *) NULL)) == NULL)
 		lang="C";
 #endif
-	if ((nlspath = (char *) getenv ("NLSPATH")) == NULL) {
+	if ((nlspath = (char *) __libc_secure_getenv ("NLSPATH")) == NULL) {
 #if OLD_NLS_PATHS
 	    nlspath = "/nlslib/%L/%N.cat:/nlslib/%N/%L";
 #else
@@ -187,6 +189,7 @@ catopen( const char *name, int type )
 			    ++nlspath;
 			    strcpy(pathP, lang);
 			    pathP = tmp;
+			    continue;
 			} else if (*(nlspath + 1) == 'N') {
 			    char * tmp = pathP + strlen(name);
 			    if (tmp > path + sizeof (path))
@@ -197,15 +200,14 @@ catopen( const char *name, int type )
 			    ++nlspath;
 			    strcpy(pathP, name);
 			    pathP = tmp;
-			} else *(pathP++) = *nlspath;
-		    } else
-		    {
-			if (pathP >= path + sizeof (path))
-			{
-				goto error;
+			    continue;
 			}
-			*(pathP++) = *nlspath;
 		    }
+		    if (pathP >= path + sizeof (path))
+		    {
+			goto error;
+		    }
+		    *(pathP++) = *nlspath;
 		}
 		*pathP = '\0';
 		if (stat(path, &sbuf) == 0 && S_ISREG (sbuf.st_mode)) {
