@@ -146,6 +146,7 @@ getanswer(const querybuf *answer, int anslen, const char *qname, int qclass, int
 	int haveanswer, had_error;
 	int toobig = 0;
 	char tbuf[MAXDNAME+1];
+	const char *tname = qname;
 
 	host.h_name = NULL;
 	eom = answer->buf + anslen;
@@ -239,6 +240,25 @@ getanswer(const querybuf *answer, int anslen, const char *qname, int qclass, int
 			buflen -= n;
 			continue;
 		}
+		if (qtype == T_PTR && type == T_CNAME) {
+			n = dn_expand(answer->buf, eom, cp, tbuf, sizeof tbuf);
+			if (n < 0) {
+				had_error++;
+				continue;
+			}
+			cp += n;
+			/* Get canonical name. */
+			n = strlen(tbuf) + 1;	/* for the \0 */
+			if (n > buflen) {
+				had_error++;
+				continue;
+			}
+			strcpy(bp, tbuf);	/* cannot overflow */
+			tname = bp;
+			bp += n;
+			buflen -= n;
+			continue;
+		}
 		if (type != qtype) {
 			syslog(LOG_NOTICE|LOG_AUTH,
 	       "gethostby*.getanswer: asked for \"%s %s %s\", got type \"%s\"",
@@ -249,7 +269,7 @@ getanswer(const querybuf *answer, int anslen, const char *qname, int qclass, int
 		}
 		switch (type) {
 		case T_PTR:
-			if (strcasecmp(qname, bp) != 0) {
+			if (strcasecmp(tname, bp) != 0) {
 				syslog(LOG_NOTICE|LOG_AUTH,
 				       AskedForGot, qname, bp);
 				cp += n;
@@ -294,6 +314,14 @@ getanswer(const querybuf *answer, int anslen, const char *qname, int qclass, int
 			} else {
 				register int nn;
 
+				if (class == C_IN && n != INT32SZ) {
+					cp += n;
+					syslog(LOG_NOTICE|LOG_AUTH,
+	"gethostby*.getanswer: got strange A record (size=%d) for \"%s\"\n",
+					       n, host.h_name);
+					continue;
+				}
+
 				host.h_length = n;
 				host.h_addrtype = (class == C_IN)
 						  ? AF_INET
