@@ -67,27 +67,6 @@ extern long	lseek();
 #include "nl_types.h"
 #endif
 
-static u_int	fix_buf_size();
-
-static bool_t	xdrrec_getlong();
-static bool_t	xdrrec_putlong();
-static bool_t	xdrrec_getbytes();
-static bool_t	xdrrec_putbytes();
-static u_int	xdrrec_getpos();
-static bool_t	xdrrec_setpos();
-static long *	xdrrec_inline();
-static void	xdrrec_destroy();
-
-static struct  xdr_ops xdrrec_ops = {
-	xdrrec_getlong,
-	xdrrec_putlong,
-	xdrrec_getbytes,
-	xdrrec_putbytes,
-	xdrrec_getpos,
-	xdrrec_setpos,
-	xdrrec_inline,
-	xdrrec_destroy
-};
 
 /*
  * A record is composed of one or more record fragments.
@@ -110,17 +89,19 @@ typedef struct rec_strm {
 	/*
 	 * out-goung bits
 	 */
-	int (*writeit)();
-	caddr_t out_base;	/* output buffer (points to frag header) */
+/* 	int (*writeit)( void *, void *, int ); */
+	WRITE_IT;
+	caddr_t out_base;	   /* output buffer (points to frag header) */
 	caddr_t out_finger;	/* next output position */
 	caddr_t out_boundry;	/* data cannot up to this address */
 	u_long *frag_header;	/* beginning of curren fragment */
-	bool_t frag_sent;	/* true if buffer sent in middle of record */
+	bool_t frag_sent;	   /* true if buffer sent in middle of record */
 	/*
 	 * in-coming bits
 	 */
-	int (*readit)();
-	u_long in_size;	/* fixed size of the input buffer */
+/* 	int (*readit)( void *, void *, int ); */
+	READ_IT;
+	u_long in_size;      /* fixed size of the input buffer */
 	caddr_t in_base;
 	caddr_t in_finger;	/* location of next byte to be had */
 	caddr_t in_boundry;	/* can read up to this location */
@@ -130,14 +111,74 @@ typedef struct rec_strm {
 	u_int recvsize;
 } RECSTREAM;
 
+#ifdef __STDC__
+static bool_t   flush_out          ( register RECSTREAM *, bool_t );
+static bool_t   fill_input_buf     ( register RECSTREAM * );
+static bool_t   get_input_bytes    ( register RECSTREAM *, register caddr_t,
+                                     register int );
+static bool_t   set_input_fragment ( register RECSTREAM * );
+static bool_t   skip_input_bytes   ( register RECSTREAM *, long );
+static u_int    fix_buf_size       ( register u_int );
+void            xdrrec_create      ( register XDR *, register u_int,
+                                     register u_int, void *,
+                                     READ_IT, WRITE_IT);
+/*                                      int (*readit)(), int (*writeit)()); */
+static bool_t   xdrrec_getlong     ( XDR *, long * );
+static bool_t   xdrrec_putlong     ( XDR *, long * );
+static bool_t   xdrrec_getbytes    ( XDR *, register caddr_t, register int );
+static bool_t   xdrrec_putbytes    ( XDR *, register caddr_t, register int );
+static u_int    xdrrec_getpos      ( register XDR * );
+static bool_t   xdrrec_setpos      ( register XDR *, u_int );
+static long *   xdrrec_inline      ( register XDR *, int );
+static void     xdrrec_destroy     ( register XDR * );
+bool_t          xdrrec_skiprecord  ( XDR * );
+bool_t          xdrrec_eof         ( XDR * );
+bool_t          xdrrec_endofrecord ( XDR *, bool_t );
+#else
+
+static bool_t   flush_out();
+static bool_t   fill_input_buf();
+static bool_t   get_input_bytes();
+static bool_t   set_input_fragment();
+static bool_t   skip_input_bytes();
+static u_int    fix_buf_size();
+void            xdrrec_create();
+static bool_t   xdrrec_getlong();
+static bool_t   xdrrec_putlong();
+static bool_t   xdrrec_getbytes();
+static bool_t   xdrrec_putbytes();
+static u_int    xdrrec_getpos();
+static bool_t   xdrrec_setpos();
+static long *   xdrrec_inline();
+static void     xdrrec_destroy();
+bool_t          xdrrec_skiprecord();
+bool_t          xdrrec_eof();
+bool_t          xdrrec_endofrecord();
+#endif	/* __STDC__ */
+
+static struct  xdr_ops xdrrec_ops = {
+	xdrrec_getlong,
+	xdrrec_putlong,
+	xdrrec_getbytes,
+	xdrrec_putbytes,
+	xdrrec_getpos,
+	xdrrec_setpos,
+	xdrrec_inline,
+	xdrrec_destroy
+};
 
 /*
  * Internal useful routines
  */
+#ifdef __STDC__
+static bool_t
+flush_out( register RECSTREAM *rstrm, bool_t eor )
+#else
 static bool_t
 flush_out(rstrm, eor)
 	register RECSTREAM *rstrm;
 	bool_t eor;
+#endif
 {
 	register u_long eormask = (eor == TRUE) ? LAST_FRAG : 0;
 	register u_long len = (u_long)(rstrm->out_finger) - 
@@ -153,9 +194,14 @@ flush_out(rstrm, eor)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static bool_t  /* knows nothing about records!  Only about input buffers */
+fill_input_buf( register RECSTREAM *rstrm )
+#else
 static bool_t  /* knows nothing about records!  Only about input buffers */
 fill_input_buf(rstrm)
 	register RECSTREAM *rstrm;
+#endif
 {
 	register caddr_t where;
 	u_int i;
@@ -173,11 +219,17 @@ fill_input_buf(rstrm)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static bool_t  /* knows nothing about records!  Only about input buffers */
+get_input_bytes( register RECSTREAM *rstrm, register caddr_t addr,
+	register int len )
+#else
 static bool_t  /* knows nothing about records!  Only about input buffers */
 get_input_bytes(rstrm, addr, len)
 	register RECSTREAM *rstrm;
 	register caddr_t addr;
 	register int len;
+#endif
 {
 	register int current;
 
@@ -197,9 +249,14 @@ get_input_bytes(rstrm, addr, len)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static bool_t  /* next two bytes of the input stream are treated as a header */
+set_input_fragment( register RECSTREAM *rstrm )
+#else
 static bool_t  /* next two bytes of the input stream are treated as a header */
 set_input_fragment(rstrm)
 	register RECSTREAM *rstrm;
+#endif
 {
 	u_long header;
 
@@ -211,10 +268,15 @@ set_input_fragment(rstrm)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static bool_t  /* consumes input bytes; knows nothing about records! */
+skip_input_bytes( register RECSTREAM *rstrm, long cnt )
+#else
 static bool_t  /* consumes input bytes; knows nothing about records! */
 skip_input_bytes(rstrm, cnt)
 	register RECSTREAM *rstrm;
 	long cnt;
+#endif
 {
 	register int current;
 
@@ -232,9 +294,14 @@ skip_input_bytes(rstrm, cnt)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static u_int
+fix_buf_size( register u_int s )
+#else
 static u_int
 fix_buf_size(s)
 	register u_int s;
+#endif
 {
 
 	if (s < 100)
@@ -250,8 +317,16 @@ fix_buf_size(s)
  * tcp_handle is an opaque handle that is passed as the first parameter to
  * the procedures readit and writeit.  Readit and writeit are read and
  * write respectively.   They are like the system
- * calls expect that they take an opaque handle rather than an fd.
+ * calls except that they take an opaque handle rather than an fd.
  */
+
+#ifdef __STDC__
+void
+xdrrec_create( register XDR *xdrs, register u_int sendsize,
+	register u_int recvsize, void *tcp_handle,
+	READ_IT, WRITE_IT )
+/* 	int (*readit)(), int (*writeit)()) */
+#else
 void
 xdrrec_create(xdrs, sendsize, recvsize, tcp_handle, readit, writeit)
 	register XDR *xdrs;
@@ -260,6 +335,7 @@ xdrrec_create(xdrs, sendsize, recvsize, tcp_handle, readit, writeit)
 	caddr_t tcp_handle;
 	int (*readit)();  /* like read, but pass it a tcp_handle, not sock */
 	int (*writeit)();  /* like write, but pass it a tcp_handle, not sock */
+#endif
 {
 	register RECSTREAM *rstrm =
 		(RECSTREAM *)mem_alloc(sizeof(RECSTREAM));
@@ -328,10 +404,15 @@ xdrrec_create(xdrs, sendsize, recvsize, tcp_handle, readit, writeit)
  * xdr handle filled in by xdrrec_create.
  */
 
+#ifdef __STDC__
+static bool_t
+xdrrec_getlong( XDR *xdrs, long *lp )
+#else
 static bool_t
 xdrrec_getlong(xdrs, lp)
 	XDR *xdrs;
 	long *lp;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)(xdrs->x_private);
 	register long *buflp = (long *)(rstrm->in_finger);
@@ -351,10 +432,15 @@ xdrrec_getlong(xdrs, lp)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static bool_t
+xdrrec_putlong( XDR *xdrs, long *lp )
+#else
 static bool_t
 xdrrec_putlong(xdrs, lp)
 	XDR *xdrs;
 	long *lp;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)(xdrs->x_private);
 	register long *dest_lp = ((long *)(rstrm->out_finger));
@@ -375,11 +461,16 @@ xdrrec_putlong(xdrs, lp)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static bool_t  /* must manage buffers, fragments, and records */
+xdrrec_getbytes( XDR *xdrs, register caddr_t addr, register int len )
+#else
 static bool_t  /* must manage buffers, fragments, and records */
 xdrrec_getbytes(xdrs, addr, len)
 	XDR *xdrs;
 	register caddr_t addr;
 	register u_int len;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)(xdrs->x_private);
 	register int current;
@@ -403,11 +494,16 @@ xdrrec_getbytes(xdrs, addr, len)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static bool_t
+xdrrec_putbytes( XDR *xdrs, register caddr_t addr, register int len )
+#else
 static bool_t
 xdrrec_putbytes(xdrs, addr, len)
 	XDR *xdrs;
 	register caddr_t addr;
 	register u_int len;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)(xdrs->x_private);
 	register int current;
@@ -428,9 +524,14 @@ xdrrec_putbytes(xdrs, addr, len)
 	return (TRUE);
 }
 
+#ifdef __STDC__
+static u_int
+xdrrec_getpos( register XDR *xdrs )
+#else
 static u_int
 xdrrec_getpos(xdrs)
 	register XDR *xdrs;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)xdrs->x_private;
 	register long pos;
@@ -454,10 +555,15 @@ xdrrec_getpos(xdrs)
 	return ((u_int) pos);
 }
 
+#ifdef __STDC__
+static bool_t
+xdrrec_setpos( register XDR *xdrs, u_int pos )
+#else
 static bool_t
 xdrrec_setpos(xdrs, pos)
 	register XDR *xdrs;
 	u_int pos;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)xdrs->x_private;
 	u_int currpos = xdrrec_getpos(xdrs);
@@ -486,14 +592,20 @@ xdrrec_setpos(xdrs, pos)
 				return (TRUE);
 			}
 			break;
+		default: break;
 		}
 	return (FALSE);
 }
 
+#ifdef __STDC__
+static long *
+xdrrec_inline( register XDR *xdrs, int len )
+#else
 static long *
 xdrrec_inline(xdrs, len)
 	register XDR *xdrs;
 	int len;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)xdrs->x_private;
 	long * buf = NULL;
@@ -515,13 +627,19 @@ xdrrec_inline(xdrs, len)
 			rstrm->in_finger += len;
 		}
 		break;
+	default: break;
 	}
 	return (buf);
 }
 
+#ifdef __STDC__
+static void
+xdrrec_destroy( register XDR *xdrs )
+#else
 static void
 xdrrec_destroy(xdrs)
 	register XDR *xdrs;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)xdrs->x_private;
 
@@ -539,9 +657,15 @@ xdrrec_destroy(xdrs)
  * Before reading (deserializing from the stream, one should always call
  * this procedure to guarantee proper record alignment.
  */
+
+#ifdef __STDC__
+bool_t
+xdrrec_skiprecord( XDR *xdrs )
+#else
 bool_t
 xdrrec_skiprecord(xdrs)
 	XDR *xdrs;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)(xdrs->x_private);
 
@@ -561,9 +685,14 @@ xdrrec_skiprecord(xdrs)
  * Returns TRUE iff there is no more input in the buffer 
  * after consuming the rest of the current record.
  */
+#ifdef __STDC__
+bool_t
+xdrrec_eof( XDR *xdrs )
+#else
 bool_t
 xdrrec_eof(xdrs)
 	XDR *xdrs;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)(xdrs->x_private);
 
@@ -585,10 +714,15 @@ xdrrec_eof(xdrs)
  * (output) tcp stream.  (This let's the package support batched or
  * pipelined procedure calls.)  TRUE => immmediate flush to tcp connection.
  */
+#ifdef __STDC__
+bool_t
+xdrrec_endofrecord( XDR *xdrs, bool_t sendnow )
+#else
 bool_t
 xdrrec_endofrecord(xdrs, sendnow)
 	XDR *xdrs;
 	bool_t sendnow;
+#endif
 {
 	register RECSTREAM *rstrm = (RECSTREAM *)(xdrs->x_private);
 	register u_long len;  /* fragment length */
