@@ -27,7 +27,7 @@ DEFUN (strsep, (pp, delim),
 
   if (!(p = *pp))
     return 0;
-  if (q = strpbrk (p, delim))
+  if ((q = strpbrk (p, delim)))
     {
       *pp = q + 1;
       *q = '\0';
