@@ -1,5 +1,11 @@
 #include <ansidecl.h>
 #include <netinet/in.h>
+#ifdef __linux__
+# include <linux/version.h>
+# if defined(LINUX_VERSION_CODE) && LINUX_VERSION_CODE >= 131328
+#  include <asm/byteorder.h>
+# endif
+#endif
 
 #undef ntohl
 #undef ntohs
@@ -9,10 +15,6 @@
 #undef __ntohs
 #undef __htonl
 #undef __htons
-#ifndef __ELF__
-#define __htonl htonl
-#define __htons htons
-#endif
 
 extern unsigned long int        __htonl(unsigned long int);
 extern unsigned short int       __htons(unsigned short int);
@@ -20,13 +22,21 @@ extern unsigned short int       __htons(unsigned short int);
 unsigned long int
 __htonl(unsigned long int x)
 {
+#if defined(LINUX_VERSION_CODE) && LINUX_VERSION_CODE >= 131400
+  return ___ntohl (x);
+#else
   return __ntohl (x);
+#endif
 }
 
 unsigned short int
 __htons(unsigned short int x)
 {
+#if defined(LINUX_VERSION_CODE) && LINUX_VERSION_CODE >= 131400
+  return ___ntohs (x);
+#else
   return __ntohs (x);
+#endif
 }
 
 #include <gnu-stabs.h>
