@@ -35,11 +35,6 @@ DEFUN(__isnan, (value), double value)
 }
 
 #include <gnu-stabs.h>
-#ifdef __ELF__
 #ifdef weak_alias
 weak_alias (__isnan, isnan);
 #endif
-#else
-function_alias(isnan, __isnan, int, (value),
-	       DEFUN(isinfl, (value), double value));
-#endif
