@@ -33,8 +33,7 @@ DEFUN(__isqnan, (value), double value)
      NaN is quiet, the highest bit in the
      mantissa is set.  */
   return ((u->ieee_nan.exponent & 0x7ff) == 0x7ff &&
-	  (u->ieee_nan.quiet_nan != 0) &&
-	  (u->ieee_nan.mantissa0 != 0 || u->ieee_nan.mantissa1 != 0));
+	  (u->ieee_nan.quiet_nan != 0));
 }
 
 #include <gnu-stabs.h>
