@@ -38,11 +38,6 @@ DEFUN(__issnan, (value), double value)
 }
 
 #include <gnu-stabs.h>
-#ifdef __ELF__
 #ifdef weak_alias
 weak_alias (__issnan, issnan);
 #endif
-#else
-function_alias(issnan,__issnan, int, (value),
-	       DEFUN(isinfl, (value), double value));
-#endif
