@@ -31,7 +31,7 @@ DEFUN(__issnanl, (value), long double value)
   /* IEEE 854 NaN's have the maximum possible
      exponent and a nonzero mantissa.  */
   return ((u->ieee_nan.exponent & 0x7fff) == 0x7fff &&
-	  (u->ieee_nan.quiet_nan == 0) &&
+	  (u->ieee_nan.quiet_nan == 0) && (u->ieee_nan.one == 1) &&
 	  (u->ieee_nan.mantissa0 != 0 || u->ieee_nan.mantissa1 != 0));
 }
 
