@@ -1,3 +1,9 @@
+#ifdef __ELF__
+/* #pragma weak getsockopt */
+int getsockopt (int, int, int, void *, int *) __attribute__ (( weak ));
+
+#endif
+
 #include <syscall.h>
 #include <sys/socket.h>
 #include <sys/socketcall.h>
@@ -20,7 +26,3 @@ getsockopt (int fd, int level, int optname, void *optval, int *optlen)
 	args[4]=(unsigned long)optlen;
 	return (socketcall (SYS_GETSOCKOPT, args));
 }
-
-#ifdef __ELF__
-#pragma weak getsockopt
-#endif
