@@ -168,6 +168,8 @@ Cambridge, MA 02139, USA.  */
 
 #else /* __SVR4_I386_ABI_L1__ */
 
+#ifndef __GPROF__
+
 #define	PSEUDO(name, syscall_name, args)				      \
   .text;								      \
   ENTRY (name)								      \
@@ -190,6 +192,38 @@ Cambridge, MA 02139, USA.  */
     movl %ebp,%esp;							      \
     popl %ebp;
  
+#else 
+
+#define	PSEUDO(name, syscall_name, args)				      \
+  .data;							   	      \
+    .align 4;								      \
+  LL(Lprof);								      \
+    .long 0;								      \
+  .text;								      \
+  ENTRY (name)								      \
+    pushl %ebp;								      \
+    movl %esp,%ebp;							      \
+    movl L(Lprof),%edx;							      \
+    call mcount;	    					              \
+    PUSH_##args								      \
+    movl $(SYS_##syscall_name), %eax;					      \
+    MOVE_##args								      \
+    int $0x80;								      \
+    movl %eax,%edx;							      \
+    check_error L(Lexit);						      \
+    negl %edx;								      \
+    pushl %edx;								      \
+    call ERRNO_LOCATION;						      \
+    popl %edx;								      \
+    movl %edx,(%eax);							      \
+    movl $-1,%eax;							      \
+   LL(Lexit)								      \
+    POP_##args								      \
+    movl %ebp,%esp;							      \
+    popl %ebp;
+ 
+#endif /* __GPROF__ */
+
 #endif /* __SVR4_I386_ABI_L1__ */
 
 #endif /* PIC */
