@@ -6,7 +6,8 @@
 int
 __ioctl(int fildes, int cmd, ...)
 {
-	register int res asm ("%d0") = SYS_ioctl;
+	int res;
+	register int d0 asm ("%d0");
 	va_list arg;
 
 	va_start(arg,cmd);
@@ -14,9 +15,10 @@ __ioctl(int fildes, int cmd, ...)
                 "movel %3,%/d2\n\t"
                 "movel %4,%/d3\n\t"
                 "trap #0\n\t"
-		:"=g" (res)
-		:"0" (SYS_ioctl),"g" (fildes),"g" (cmd), "d" (va_arg(arg,int))
+		:"=g" (d0)
+		:"0" (SYS_ioctl),"g" (fildes),"g" (cmd), "g" (va_arg(arg,int))
                 : "%d0", "%d1", "%d2", "%d3");
+	res = d0;
 	if (res>=0)
 		return res;
 	errno = -res;
