@@ -48,6 +48,18 @@ Cambridge, MA 02139, USA.  */
 
 #else /* PTHREAD_KERNEL */
 
+/* In case of returning a memory address, negative values may not mean
+   error.  Moreover, we have to copy the return value to register %a0,
+   as those syscalls are normally declared to return a pointer.  */
+
+#ifdef __CHECK_RETURN_ADDR
+#define check_error(LAB)	cmp.l _HASH -4096, %d0; jls LAB
+#define copy_ret		move.l %d0, %a0
+#else
+#define check_error(LAB)	tst.l %d0; jpl LAB
+#define copy_ret		/* empty */
+#endif
+
 #define ERRNO_LOCATION SYMBOL_NAME(__errno_location)
 
 #if defined(__PIC__) || defined (__pic__)
@@ -58,14 +70,14 @@ Cambridge, MA 02139, USA.  */
     movel _HASH SYS_##syscall_name,%d0;					      \
     MOVE_##args 							      \
     trap  _HASH 0;							      \
-    tstl  %d0; 								      \
-    jpl   1f;								      \
+    check_error(1f);							      \
     negl  %d0;								      \
     movel %d0,%sp@-;							      \
     bsrl  ERRNO_LOCATION@PLTPC;						      \
     movel %sp@+,%a0@;							      \
     moveq _HASH -1,%d0;							      \
-   1:POP_##args
+ 1: copy_ret;								      \
+    POP_##args
 
 #else /* PIC */
 
@@ -76,14 +88,14 @@ Cambridge, MA 02139, USA.  */
     movel _HASH SYS_##syscall_name,%d0;					      \
     MOVE_##args 							      \
     trap  _HASH 0;							      \
-    tstl  %d0; 								      \
-    jpl   1f;								      \
+    check_error(1f);							      \
     negl  %d0;								      \
     movel %d0,%sp@-;							      \
     jbsr  ERRNO_LOCATION;						      \
     movel %sp@+,%a0@;							      \
     moveq _HASH -1,%d0;							      \
-   1:POP_##args
+ 1: copy_ret;								      \
+    POP_##args
 
 #endif /* PIC */
 
