@@ -1,5 +1,13 @@
 #include <ansidecl.h>
 #include <netinet/in.h>
+#ifdef __linux__
+# include <linux/version.h>
+# ifdef LINUX_VERSION_CODE
+#  if LINUX_VERSION_CODE >= 131328
+#   include <asm/byteorder.h>
+#  endif
+# endif
+#endif
 
 #undef ntohl
 #undef ntohs
