@@ -56,6 +56,7 @@ static const char rcsid[] = "fd_kern.c,v 1.6 1995/09/13 02:10:28 hjl Exp";
 #include <sys/stat.h>
 #include <termios.h>
 #include <pthread/mit/sys/compat.h>
+#include <pthread/mit/machdep.h>
 #else
 #include <sys/compat.h>
 #endif
@@ -74,6 +75,146 @@ static const char rcsid[] = "fd_kern.c,v 1.6 1995/09/13 02:10:28 hjl Exp";
 
 #undef creat
 
+extern int  machdep_sys_select        (int, fd_set *, fd_set *, fd_set *, 
+                                       struct timeval * tv);
+extern void pthread_resched_resume    (enum pthread_state);
+extern void pthread_sched_resume      (void);
+extern DIR *__libc_opendir            (__const char *);
+extern struct dirent *__libc_readdir  (DIR * __dirp);
+extern int  __libc_closedir           (DIR * __dirp);
+
+/*
+ * These functions don't seem to be implemented. vch
+ */
+extern int  __machdep_sys_ioctl       (int, int, struct termios *);
+extern int  sleep_cancel              (struct pthread * );
+extern void sig_handler_pause         (void);
+extern void machdep_sys_sigprocmask   (int, sigset_t *, sigset_t *);
+extern int	machdep_sys_lseek         (int, int, int);
+extern int  machdep_sys_open          (char *, int, ...);
+extern int  machdep_sys_close         (int);
+extern int  machdep_sys_pipe          (int *);
+extern int  machdep_sys_fchown        (int, uid_t, gid_t);
+extern int  machdep_sys_fchmod        (int, mode_t);
+extern int  machdep_sys_dup           (int);
+extern int  machdep_sys_dup2          (int, int);
+extern int  machdep_sys_ftruncate     (int, size_t);
+extern int  machdep_sys_ioctl         (int, unsigned long, caddr_t);
+
+/*
+ * Prototypes
+ */
+#if defined (HAVE_SYSCALL_SENDTO) && !defined (HAVE_SYSCALL_SEND)
+pthread_ssize_t      machdep_sys_send      (int, const void *, size_t, int);
+#endif
+#if defined (HAVE_SYSCALL_RECVFROM) && !defined (HAVE_SYSCALL_RECV)
+pthread_ssize_t      machdep_sys_recv      (int, void *, size_t, int);
+#endif
+void                 fd_kern_poll          (void);
+void                 fd_kern_wait          (void);
+pthread_ssize_t      __fd_kern_read        (union fd_data, int, void *, size_t,
+                                            struct timespec *);
+int                  __fd_kern_readv       (union fd_data, int,
+                                            const struct iovec *, int,
+                                            struct timespec *);
+pthread_ssize_t      __fd_kern_write       (union fd_data, int, const void *,
+                                            size_t, struct timespec *);
+int                  __fd_kern_writev      (union fd_data, int,
+                                            const struct iovec *, int,
+                                            struct timespec *);
+int                  __fd_kern_fcntl       (union fd_data, int, int, int);
+int                  __fd_kern_close       (union fd_data, int);
+off_t                __fd_kern_lseek       (union fd_data, int, off_t, int);
+int                  open                  (const char *, int, ...);
+#ifndef __ELF__
+int                  create                (const char *, mode);
+#endif
+int                  creat                 (const char *, mode_t);
+int                  fchown                (int, uid_t, gid_t);
+int                  fchmod                (int, mode_t);
+int                  ftruncate             (int, size_t);
+int                  pipe                  (int fds[2]);
+void                 fd_kern_reset         (int);
+#ifdef __linux__
+static inline int    isatty_basic          (int);
+static inline char * ttyname_r_basic       (int, char *, int);
+#endif
+void                 fd_kern_init          (int);
+static int           fd_kern_gettableentry (const int, int);
+int                  fd_kern_exec          (const int);
+void                 fd_kern_fork          (void);
+#if defined (HAVE_SYSCALL_SOCKET) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  socket                (int, int, int);
+#endif
+#if defined (HAVE_SYSCALL_BIND) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  bind                  (int, const struct sockaddr *, int);
+#endif
+#if defined (HAVE_SYSCALL_CONNECT) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  connect               (int, const struct sockaddr *, int);
+#endif
+#if defined (HAVE_SYSCALL_ACCEPT) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  accept                (int, const struct sockaddr *,
+                                            int *);
+#endif
+#if defined (HAVE_SYSCALL_LISTEN) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  listen                (int, int); 
+#endif
+#if defined (HAVE_SYSCALL_SEND) || defined (HAVE_SYSCALL_SOCKETCALL)
+ssize_t              send_timedwait        (int, void *, size_t, unsigned int,
+                                            struct timespec *);
+ssize_t              send                  (int, const void *, size_t, unsigned int);
+#endif
+#if defined (HAVE_SYSCALL_SENDTO) || defined (HAVE_SYSCALL_SOCKETCALL)
+ssize_t              sendto_timedwait      (int, void *, size_t, unsigned int,
+                                            struct sockaddr *, int,
+                                            struct timespec *);
+ssize_t              sendto                (int, const void *, size_t,
+                                            unsigned int,
+                                            const struct sockaddr *, int);
+#endif
+#if defined (HAVE_SYSCALL_SENDMSG) || defined (HAVE_SYSCALL_SOCKETCALL)
+ssize_t              sendmsg_timedwait     (int, const struct msghdr *, int,
+                                            struct timespec *);
+ssize_t              sendmsg               (int, const struct msghdr *,
+                                            unsigned int);
+#endif
+#if defined (HAVE_SYSCALL_RECV) || defined (HAVE_SYSCALL_SOCKETCALL)
+ssize_t              recv_timedwait        (int, void *, size_t,
+                                            unsigned int, struct timespec *);
+ssize_t              recv(int, void *, size_t, unsigned int);
+#endif
+#if defined (HAVE_SYSCALL_RECVFROM) || defined (HAVE_SYSCALL_SOCKETCALL)
+ssize_t              recvfrom_timedwait    (int, void *, size_t, int,
+                                            struct sockaddr *, int *,
+                                            struct timespec *);
+ssize_t              recvfrom              (int, void *, size_t, unsigned int,
+                                            struct sockaddr *, int *);
+#endif
+#if defined (HAVE_SYSCALL_RECVMSG) || defined (HAVE_SYSCALL_SOCKETCALL)
+ssize_t              recvmsg_timedwait     (int, struct msghdr *, int,
+                                            struct timespec *); 
+#endif
+#if defined (HAVE_SYSCALL_SHUTDOWN) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  shutdown              (int, int);
+#endif
+#if defined (HAVE_SYSCALL_SETSOCKOPT) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  setsockopt            (int, int, int, const void *, int);
+#endif
+#if defined (HAVE_SYSCALL_GETPEERNAME) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  getpeername           (int, struct sockaddr *, int *);
+#endif
+#if defined (HAVE_SYSCALL_GETSOCKOPT) || defined (HAVE_SYSCALL_SOCKETCALL)
+int                  getsockopt            (int, int, int, void *, int *);
+#endif
+
+/*
+ * End of prototypes.
+ */
+
+/*
+ * Begin Functions.
+ */
+
 #if defined (HAVE_SYSCALL_SENDTO) && !defined (HAVE_SYSCALL_SEND)
 
 pthread_ssize_t machdep_sys_send (int fd, const void *msg, size_t len,
@@ -109,7 +250,8 @@ struct pthread_queue fd_wait_select = PTHREAD_QUEUE_INITIALIZER;
  *
  * This function uses a linked list of waiting pthreads, NOT a queue.
  */ 
-void fd_kern_poll()
+
+void fd_kern_poll(void)
 {
 	struct timeval __fd_kern_poll_timeout = { 0, 0 };
 	fd_set fd_set_read, fd_set_write, fd_set_except;
@@ -230,7 +372,7 @@ void fd_kern_poll()
  */
 extern struct timeval __fd_kern_wait_timeout;
 
-void fd_kern_wait()
+void fd_kern_wait(void)
 {
 	fd_set fd_set_read, fd_set_write, fd_set_except;
 	struct pthread *pthread, *deq;
@@ -372,8 +514,12 @@ void fd_kern_wait()
 /* ==========================================================================
  * read()
  */
-pthread_ssize_t __fd_kern_read(union fd_data fd_data, int flags, void *buf,
-  size_t nbytes, struct timespec * timeout)
+/*
+ * GCC throws out the 'const' from 'const void *buf'. vch
+ */
+pthread_ssize_t __fd_kern_read(union fd_data fd_data, int flags,
+                               void *buf, size_t nbytes,
+                               struct timespec * timeout)
 {
 	int fd = fd_data.i;
 	int ret;
@@ -422,8 +568,12 @@ pthread_ssize_t __fd_kern_read(union fd_data fd_data, int flags, void *buf,
 /* ==========================================================================
  * readv()
  */
-int __fd_kern_readv(union fd_data fd_data, int flags, const struct iovec *iov,
-  int iovcnt, struct timespec * timeout)
+/*
+ * GCC throws out the 'const' from 'const void *buf'. vch
+ */
+int __fd_kern_readv(union fd_data fd_data, int flags,
+                    const struct iovec *iov, int iovcnt,
+                    struct timespec * timeout)
 {
 	int fd = fd_data.i;
 	int ret;
@@ -472,8 +622,12 @@ int __fd_kern_readv(union fd_data fd_data, int flags, const struct iovec *iov,
 /* ==========================================================================
  * write()
  */
+/*
+ * GCC throws out the 'const' from 'const void *buf'. vch
+ */
 pthread_ssize_t __fd_kern_write(union fd_data fd_data, int flags,
- const void *buf, size_t nbytes, struct timespec * timeout)
+                                const void *buf, size_t nbytes,
+                                struct timespec * timeout)
 {
 	int fd = fd_data.i;
 	int ret;
@@ -522,8 +676,12 @@ pthread_ssize_t __fd_kern_write(union fd_data fd_data, int flags,
 /* ==========================================================================
  * writev()
  */
-int __fd_kern_writev(union fd_data fd_data, int flags, const struct iovec *iov,
-  int iovcnt, struct timespec * timeout)
+/*
+ * GCC throws out the 'const' from 'const void *buf'. vch
+ */
+int __fd_kern_writev(union fd_data fd_data, int flags,
+                     const struct iovec *iov, int iovcnt,
+                     struct timespec * timeout)
 {
 	int fd = fd_data.i;
 	int ret;
@@ -603,12 +761,22 @@ off_t __fd_kern_lseek(union fd_data fd_data, int f, off_t offset, int whence)
 /*
  * File descriptor operations
  */
-extern machdep_sys_close();
 
+/* 
+ * Why do some of these produce:
+ * 'warning: initialization from incompatible pointer type'
+ * and others do not??? vch
+ */
 /* Normal file operations */
 static struct fd_ops __fd_kern_ops = {
-	__fd_kern_write, __fd_kern_read, __fd_kern_close, __fd_kern_fcntl,
-	__fd_kern_writev, __fd_kern_readv, __fd_kern_lseek, 1
+	__fd_kern_write, 
+   __fd_kern_read,
+   __fd_kern_close,
+   __fd_kern_fcntl,
+	__fd_kern_writev,
+   __fd_kern_readv,
+   __fd_kern_lseek,
+   1
 };
 
 /* NFS file opperations */
@@ -629,6 +797,10 @@ static struct fd_ops __fd_kern_ops = {
  *
  * A regular file on the local system needs no special treatment.
  */
+/*
+ * GCC throws out the 'const' from 'const void *buf'. vch
+ */
+
 int open(const char *path, int flags, ...)
 {
 	int fd, mode, fd_kern;
@@ -677,6 +849,7 @@ int open(const char *path, int flags, ...)
 /* ==========================================================================
  * create()
  */
+
 int create(const char *path, mode_t mode)
 {
   return creat (path, mode);
@@ -688,6 +861,10 @@ int create(const char *path, mode_t mode)
  */
 #undef creat
 
+/*
+ * The 'const' in 'const char *path' gets discarded by GCC.  The SYSV
+ * manual doesn't require it for 'ctreat' or 'open'. vch
+ */
 int creat(const char *path, mode_t mode)
 {
   return open (path, O_CREAT | O_TRUNC | O_WRONLY, mode);
@@ -755,10 +932,14 @@ int pipe(int fds[2])
 	if ((fds[0] = fd_allocate()) >= OK) {
 		if ((fds[1] = fd_allocate()) >= OK) {
 			if ((ret = machdep_sys_pipe(kfds)) >= OK) {
-				fd_table[fds[0]]->flags = machdep_sys_fcntl(kfds[0], F_GETFL, NULL);
-				machdep_sys_fcntl(kfds[0], F_SETFL, fd_table[fds[0]]->flags | __FD_NONBLOCK);
-				fd_table[fds[1]]->flags = machdep_sys_fcntl(kfds[1], F_GETFL, NULL);
-				machdep_sys_fcntl(kfds[1], F_SETFL, fd_table[fds[1]]->flags | __FD_NONBLOCK);
+				fd_table[fds[0]]->flags = machdep_sys_fcntl(kfds[0],
+                     F_GETFL, (int)NULL);
+				machdep_sys_fcntl(kfds[0], F_SETFL, (int)fd_table[fds[0]]->flags
+                     | __FD_NONBLOCK);
+				fd_table[fds[1]]->flags = machdep_sys_fcntl(kfds[1], F_GETFL,
+                     (int)NULL);
+				machdep_sys_fcntl(kfds[1], F_SETFL, (int)fd_table[fds[1]]->flags
+                     | __FD_NONBLOCK);
 
 				fd_table[fds[0]]->ops = &(__fd_kern_ops);
 				fd_table[fds[1]]->ops = &(__fd_kern_ops);
@@ -812,7 +993,6 @@ isatty_basic (int fd)
   return __machdep_sys_ioctl(fd, TCGETS, &term) == 0;
 }
 
-
 /* Return the pathname of the terminal FD is open on, or NULL on errors.
    The returned storage is good only until the next call to this function.  */
 static inline char *
@@ -875,7 +1055,8 @@ ttyname_r_basic (int fd, char *name, int namelen)
  */
 void fd_kern_init(int fd)
 {
-	if ((fd_table[fd]->flags = machdep_sys_fcntl(fd, F_GETFL, NULL)) >= OK) {
+	if ((fd_table[fd]->flags = machdep_sys_fcntl(fd, F_GETFL,
+                                               (int)NULL)) >= OK) {
 		if (isatty_basic(fd)) {
 			int new_fd;
 #ifdef __linux__
@@ -1000,7 +1181,7 @@ int fd_kern_exec(const int child)
 		 * descriptor number fd is actually in use by the program, we have
          * to move it out of the way
 		 */
-		if ((machdep_sys_fcntl(fd, F_GETFL, NULL)) >= OK) {
+		if ((machdep_sys_fcntl(fd, F_GETFL, (int)NULL)) >= OK) {
 			/* fd is busy */
 			int j;
 
@@ -1186,7 +1367,8 @@ int connect(int fd, const struct sockaddr *name, int namelen)
 	int ret, tmpnamelen;
 
 	if ((ret = fd_lock(fd, FD_RDWR, NULL)) == OK) {
-		if ((ret = machdep_sys_connect(fd_table[fd]->fd.i, name, namelen)) < OK) {
+		if ((ret = machdep_sys_connect(fd_table[fd]->fd.i, name, namelen))
+         < OK) {
             if (!(fd_table[fd]->flags & __FD_NONBLOCK) &&
               ((ret == -EWOULDBLOCK) || (ret == -EINPROGRESS) ||
 		      (ret == -EALREADY) || (ret == -EAGAIN))) {
@@ -1226,12 +1408,19 @@ int connect(int fd, const struct sockaddr *name, int namelen)
 /* ==========================================================================
  * accept()
  */
+/* 
+ * GCC discards the 'const' from 'const struct sockaddr' so it should be
+ * deleted from the definition.  However, I didn't want to change
+ * <socket.h>. THe 'const' is not required by the SYSV manual. vch
+ * 
+ */
 int accept(int fd, const struct sockaddr *name, int *namelen)
 {
 	int ret, fd_kern;
 
 	if ((ret = fd_lock(fd, FD_RDWR, NULL)) == OK) {
-		while ((fd_kern = machdep_sys_accept(fd_table[fd]->fd.i, name, namelen)) < OK) {
+		while ((fd_kern = machdep_sys_accept(fd_table[fd]->fd.i, name, namelen))
+         < OK) {
             if (!(fd_table[fd]->flags & __FD_NONBLOCK) &&
               ((fd_kern == -EWOULDBLOCK) || (fd_kern == -EAGAIN))) {
 				pthread_sched_prevent();
@@ -1294,7 +1483,12 @@ int listen(int fd, int backlog)
 /* ==========================================================================
  * send_timedwait()
  */
-ssize_t send_timedwait(int fd, const void * msg, size_t len,
+/*  Changed from:
+ * ssize_t send_timedwait(int fd, const void * msg, size_t len,
+ *      unsigned int flags, struct timespec * timeout)
+ *  Because gcc discards 'const' anyhow. vch
+ */
+ssize_t send_timedwait(int fd, void * msg, size_t len,
   unsigned int flags, struct timespec * timeout)
 {
 	int ret;
@@ -1347,6 +1541,11 @@ ssize_t send_timedwait(int fd, const void * msg, size_t len,
 /* ==========================================================================
  * send()
  */
+/*  
+ *  GCC discards the 'const' from 'const void * msg'.  It isn't required
+ *  according the the SYSV manual.  I left it in because I didn't want
+ *  change <socket.h>. vch
+ */
 ssize_t send(int fd, const void * msg, size_t len, unsigned int flags)
 {
 	return(send_timedwait(fd, msg, len, flags, NULL));
@@ -1359,8 +1558,14 @@ ssize_t send(int fd, const void * msg, size_t len, unsigned int flags)
 /* ==========================================================================
  * sendto_timedwait()
  */
-ssize_t sendto_timedwait(int fd, const void * msg, size_t len,
- unsigned int flags, const struct sockaddr *to, int to_len,
+/*  Changed from:
+ * ssize_t sendto_timedwait(int fd, const void * msg, size_t len,
+ *        unsigned int flags, const struct sockaddr *to, int to_len,
+ *        struct timespec * timeout)
+ *  Because gcc discards 'const' anyhow. vch
+ */
+ssize_t sendto_timedwait(int fd, void * msg, size_t len,
+ unsigned int flags, struct sockaddr *to, int to_len,
  struct timespec * timeout)
 {
 	int ret;
@@ -1413,8 +1618,11 @@ ssize_t sendto_timedwait(int fd, const void * msg, size_t len,
 /* ==========================================================================
  * sendto()
  */
+/*
+ * GCC throws out the 'const' from 'const void *buf'. vch
+ */
 ssize_t sendto(int fd, const void * msg, size_t len, unsigned int flags,
-  const struct sockaddr *to, int to_len)
+               const struct sockaddr *to, int to_len)
 {
 	return(sendto_timedwait(fd, msg, len, flags, to, to_len, NULL));
 }
@@ -1426,6 +1634,9 @@ ssize_t sendto(int fd, const void * msg, size_t len, unsigned int flags,
 /* ==========================================================================
  * sendmsg_timedwait()
  */
+/*
+ * GCC throws out the 'const' from 'const struct msghdr *msg'. vch
+ */
 ssize_t sendmsg_timedwait(int fd, const struct msghdr *msg, int flags,
   struct timespec * timeout)
 {
@@ -1659,7 +1870,8 @@ ssize_t recvmsg_timedwait(int fd, struct msghdr *msg, int flags,
 	int passed_fd, ret, i;
 
 	if ((ret = fd_lock(fd, FD_READ, timeout)) == OK) {
-		while ((ret = machdep_sys_recvmsg(fd_table[fd]->fd.i, msg, flags)) < OK) {
+		while ((ret = machdep_sys_recvmsg(fd_table[fd]->fd.i, msg, flags))
+         < OK) {
             if (!(fd_table[fd]->flags & __FD_NONBLOCK) &&
 			  ((ret == -EWOULDBLOCK) || (ret == -EAGAIN))) {
 				pthread_sched_prevent();
@@ -1701,7 +1913,8 @@ ssize_t recvmsg_timedwait(int fd, struct msghdr *msg, int flags,
 		fd_unlock(fd, FD_READ);
 
 		/* Handle getting the real file descriptor */
-		for (i = 0; i < (((struct omsghdr *)msg)->msg_controllen / sizeof(i)); i++) {
+		for (i = 0; i < (((struct omsghdr *)msg)->msg_controllen / sizeof(i));
+           i++) {
 			passed_fd = *(((int *)((struct omsghdr *)msg)->msg_control) + i);
 			if (!((fd = fd_allocate()) < OK)) {
 				fd_table[fd]->flags = machdep_sys_fcntl(passed_fd, F_GETFL);
@@ -1790,6 +2003,10 @@ int shutdown(int fd, int how)
 /* ==========================================================================
  * setsockopt()
  */
+/* 
+ * GCC discards the 'const' from 'const void * optval'.  The SYSV manual
+ * doesn't designate this argument as constant.  vch
+ */
 int setsockopt(int fd, int level, int optname, const void * optval, int optlen)
 {
    int ret;
