@@ -1015,6 +1015,8 @@ struct state * const	sp;
 		(void) tzparse(GMT, sp, TRUE);
 }
 
+extern char *__libc_secure_getenv(const char *);
+
 #ifdef __STDC__
 void
 tzset(void)
@@ -1026,7 +1028,7 @@ tzset()
 	register const char *	name;
 	void tzsetwall(void);
 
-	name = getenv("TZ");
+	name = __libc_secure_getenv("TZ");
 	if (name == NULL) {
 		tzsetwall();
 		return;
