@@ -27,7 +27,7 @@
 #include <stdio.h>
 #endif
 
-#ifdef linux
+#if defined(linux) || defined(_WIN32)
 #include <string.h>
 #endif
 
@@ -74,7 +74,7 @@ static void    set_bits             ();
 STATIC void    clearmem             ();
 void init_des                       ();
 #ifdef _UFC_32_
-TATIC  void    shuffle_sb           ();
+STATIC void    shuffle_sb           ();
 #endif	/* _UFC_32_ */
 #ifdef _UFC_64_
 STATIC void    shuffle_sb           ();
@@ -367,7 +367,7 @@ static set_bits(v, b)
  * bzero and some don't have memset.
  */
 
-#ifdef __STDC__
+#if defined(__STDC__) || defined(_WIN32)
 STATIC void
 clearmem( char *start, int cnt)
 #else
